import React, { CSSProperties, PureComponent } from "react";
import { BoundingRect, NormalizedAreaSelection, NormalizedPosition, SelectionType } from "../index";
import { Coords } from "./PdfViewer";
export interface PdfPageData {
    pageRefs: Map<number, HTMLDivElement | null>;
    areaSelectionActivePage: number;
    pageDimensions?: Map<number, {
        width: number;
        height: number;
    }>;
    selectionMap?: Map<number, SelectionType[]>;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onAreaSelectionStart?: (pageNumber: number) => void;
    onAreaSelectionEnd?: (selection: NormalizedAreaSelection) => void;
}
interface PdfPageProps {
    index: number;
    style: CSSProperties;
    data: PdfPageData;
}
interface PdfPageState {
    renderComplete: boolean;
    areaSelection?: {
        originTarget?: HTMLElement;
        start?: Coords;
        position?: NormalizedPosition;
        locked?: boolean;
    };
}
export declare class PdfPage extends PureComponent<PdfPageProps, PdfPageState> {
    state: PdfPageState;
    inputRef: React.RefObject<HTMLDivElement>;
    getPageData: () => {
        pageNumber: number;
        areaSelectionActive: boolean;
        pageDimensions: {
            width: number;
            height: number;
        } | undefined;
        selections: SelectionType[] | undefined;
        pageRefs: Map<number, HTMLDivElement | null>;
        areaSelectionActivePage: number;
        selectionMap?: Map<number, SelectionType[]> | undefined;
        enableAreaSelection?: ((event: React.MouseEvent<Element, MouseEvent>) => boolean) | undefined;
        onAreaSelectionStart?: ((pageNumber: number) => void) | undefined;
        onAreaSelectionEnd?: ((selection: NormalizedAreaSelection) => void) | undefined;
    };
    _mounted: boolean;
    componentDidMount: () => void;
    componentWillUnmount: () => void;
    containerCoords: (pageX: number, pageY: number) => {
        x: number;
        y: number;
    } | undefined;
    getBoundingRect(start: Coords, end: Coords, clip?: BoundingRect): BoundingRect;
    onAreaSelectStart: (event: React.MouseEvent) => void;
    getAreaSelectionPosition: (event: MouseEvent) => NormalizedPosition | undefined;
    onAreaSelectChange: (event: MouseEvent) => void;
    onAreaSelectEnd: (event: MouseEvent) => void;
    onPageLoad: () => void;
    onPageRender: () => void;
    onMouseDown: (event: React.PointerEvent<HTMLDivElement>) => void;
    onMouseMove: (event: MouseEvent) => void;
    onMouseUp: (event: MouseEvent) => void;
    renderSelections: () => JSX.Element | null;
    render: () => JSX.Element;
}
export {};
