import React, { Component } from "react";
import { pdfjs } from "react-pdf";
import "react-pdf/dist/esm/Page/AnnotationLayer.css";
import { ListOnItemsRenderedProps, VariableSizeList } from "react-window";
import "../style/react_pdf_viewer.css";
import { NormalizedPosition, Position } from "../types";
export declare type Coords = {
    x: number;
    y: number;
};
export declare type TextSelectionType = {
    text: string;
    position: Position;
};
export declare type AreaSelectionType = {
    image: string;
    position: Position;
};
export declare type SelectionType = TextSelectionType | AreaSelectionType;
export declare type NormalizedTextSelection = {
    text: string;
    position: NormalizedPosition;
};
export declare type NormalizedAreaSelection = {
    image: string;
    position: NormalizedPosition;
};
export declare type NormalizedSelection = NormalizedTextSelection | NormalizedAreaSelection;
export declare const isAreaSelection: (selection: SelectionType) => selection is AreaSelectionType;
interface PdfViewerProps {
    url: string;
    selections?: Array<SelectionType>;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onTextSelection?: (highlightTip?: NormalizedTextSelection) => void;
    onAreaSelection?: (highlightTip?: NormalizedAreaSelection) => void;
}
interface PdfViewerState {
    documentUuid?: string;
    containerHeight: number;
    textSelectionEnabled: boolean;
    areaSelectionActivePage?: number;
    currentPage: number;
    numPages: number;
    pageDimensions?: Map<number, {
        width: number;
        height: number;
    }>;
    responsiveScale: number;
}
export declare class PdfViewer extends Component<PdfViewerProps, PdfViewerState> {
    state: PdfViewerState;
    /** Total left and right border width, needed as offset to avoid PageCanvas rendering past right page border. */
    BORDER_WIDTH_OFFSET: number;
    /** Scale value for PDF size */
    scale: number;
    containerDiv: HTMLElement | null;
    listDiv: VariableSizeList | null;
    pageRefs: Map<number, HTMLDivElement | null>;
    selectionMap: Map<number, SelectionType[]> | undefined;
    _mounted: boolean;
    /**
     * Lifecycle function
     */
    componentDidMount: () => void;
    componentDidUpdate: (prevProps: PdfViewerProps) => void;
    componentWillUnmount: () => void;
    /**
     * Helpers
     */
    resetSelections: () => void;
    computeSelectionMap: () => void;
    computePageDimensions: (pdf: pdfjs.PDFDocumentProxy) => void;
    getPageHeight: (index: number) => number;
    clearPageHeightCache: () => void;
    computeResponsiveScale: (pageNumber: number) => number | undefined;
    handleResize: () => void;
    debouncedHandleResize: () => void;
    getItemKey: (index: number) => string;
    /**
     * Text selection handlers
     */
    clearTextSelection: () => void;
    onTextSelectionStart: () => void;
    onTextSelectionChange: () => void;
    /**
     * Area selection handlers
     */
    clearAreaSelection: () => void;
    onAreaSelectionStart: (pageNumber: number) => void;
    onAreaSelectionEnd: (selection: NormalizedAreaSelection) => void;
    /**
     * Event handlers
     */
    onKeyDown: (event: KeyboardEvent) => void;
    onMouseDown: () => void;
    onDocumentLoad: (pdf: pdfjs.PDFDocumentProxy) => void;
    updateCurrentVisiblePage: ({ visibleStopIndex }: ListOnItemsRenderedProps) => void;
    render: () => JSX.Element;
}
export {};
